==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QPainterPath_Element_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QPainterPath>
#include <QtCore/QVariant>
#include <QtCore/qpoint.h>
#include <QtGui/qpainterpath.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPainterPath_Element(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPainterPath::Element")
    QPainterPath::Element *_ptr = reinterpret_cast<QPainterPath::Element *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QPainterPath_Element_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QPainterPath::Element *__qt_this = new(__qtjambi_ptr) QPainterPath::Element();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QPainterPath::Element
void __qt_destruct_QPainterPath_Element(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPainterPath::Element")
    reinterpret_cast<QPainterPath::Element*>(ptr)->~Element();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPainterPath::Element::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_initialize_1native__Lio_qt_gui_QPainterPath_00024Element_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPainterPath::Element::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPainterPath_Element_0, sizeof(QPainterPath::Element), typeid(QPainterPath::Element), false, &deleter_QPainterPath_Element, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPainterPath::Element::isCurveTo()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_isCurveTo_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPainterPath::Element::isCurveTo()const", __qt_this)
        __java_return_value = __qt_this->isCurveTo();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPainterPath::Element::isLineTo()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_isLineTo_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPainterPath::Element::isLineTo()const", __qt_this)
        __java_return_value = __qt_this->isLineTo();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPainterPath::Element::isMoveTo()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_isMoveTo_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPainterPath::Element::isMoveTo()const", __qt_this)
        __java_return_value = __qt_this->isMoveTo();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPainterPath::Element::operator QPointF()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_toPoint_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPainterPath::Element::operator QPointF()const", __qt_this)
        QPointF __qt_return_value = *__qt_this;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPainterPath::Element::operator==(QPainterPath::Element)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_equals_1native_1cref_1QPainterPath_1Element_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID e0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPainterPath::Element::operator==(QPainterPath::Element)const", __qt_this)
        const QPainterPath::Element& __qt_e0 = QtJambiAPI::valueReferenceFromNativeId<QPainterPath::Element>(e0);
        __java_return_value = (*__qt_this) == __qt_e0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_type_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QPainterPath::ElementType&  __qt_value = __qt_this->type;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_x_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->x;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_y_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->y;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPainterPath_Element(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPainterPath::Element>("QPainterPath::Element", "io/qt/gui/QPainterPath$Element");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPainterPath_Element, {
        ConstructorInfo(&__qt_construct_QPainterPath_Element_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPainterPath_Element);
    registerMetaType<QPainterPath::Element>("QPainterPath::Element");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QPainterPath_Element_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QPainterPath>
#include <QtCore/QVariant>
#include <QtCore/qpoint.h>
#include <QtGui/qpainterpath.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPainterPath_Element(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPainterPath::Element")
    QPainterPath::Element *_ptr = reinterpret_cast<QPainterPath::Element *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new Element()
void __qt_construct_QPainterPath_Element(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Element()")
    Q_UNUSED(__java_arguments)
    QPainterPath::Element *__qt_this = new(__qtjambi_ptr) QPainterPath::Element();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QPainterPath::Element::Element()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_initialize_1native__Lio_qt_gui_QPainterPath_00024Element_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPainterPath::Element::Element()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPainterPath_Element, sizeof(QPainterPath::Element), typeid(QPainterPath::Element), false, &deleter_QPainterPath_Element, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new Element(QPainterPath::Element)
void __qt_construct_QPainterPath_Element_cref_QPainterPath_Element(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Element(QPainterPath::Element)")
    jobject other0 = __java_arguments[0].l;
    const QPainterPath::Element& __qt_other0 = qtjambi_cast<const QPainterPath::Element& >(__jni_env, other0);
    QPainterPath::Element *__qt_this = new(__qtjambi_ptr) QPainterPath::Element(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPainterPath::Element::Element(QPainterPath::Element)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_initialize_1native__Lio_qt_gui_QPainterPath_00024Element_2Lio_qt_gui_QPainterPath_00024Element_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPainterPath::Element::Element(QPainterPath::Element)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPainterPath_Element_cref_QPainterPath_Element, sizeof(QPainterPath::Element), typeid(QPainterPath::Element), false, &deleter_QPainterPath_Element, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new Element{qreal,qreal,QPainterPath::ElementType}
void __qt_construct_QPainterPath_Element_qreal_qreal_QPainterPath_ElementType(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Element{qreal,qreal,QPainterPath::ElementType}")
    jdouble x0 = __java_arguments[0].d;
    Q_UNUSED(x0)
    jdouble y1 = __java_arguments[1].d;
    Q_UNUSED(y1)
    jobject type2 = __java_arguments[2].l;
    QPainterPath::ElementType __qt_type2 = qtjambi_cast<QPainterPath::ElementType>(__jni_env, type2);
    QPainterPath::Element *__qt_this = new(__qtjambi_ptr) QPainterPath::Element{static_cast<qreal>(x0), static_cast<qreal>(y1), QPainterPath::ElementType(__qt_type2)};
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPainterPath::Element::Element{qreal,qreal,QPainterPath::ElementType}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_initialize_1native__Lio_qt_gui_QPainterPath_00024Element_2DDLio_qt_gui_QPainterPath_00024ElementType_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jdouble x0,
 jdouble y1,
 jobject type2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPainterPath::Element::Element{qreal,qreal,QPainterPath::ElementType}")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].d = x0;
        arguments[1].d = y1;
        arguments[2].l = type2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPainterPath_Element_qreal_qreal_QPainterPath_ElementType, sizeof(QPainterPath::Element), typeid(QPainterPath::Element), false, &deleter_QPainterPath_Element, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPainterPath::Element
void __qt_destruct_QPainterPath_Element(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPainterPath::Element")
    reinterpret_cast<QPainterPath::Element*>(ptr)->~Element();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPainterPath::Element::isCurveTo()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_isCurveTo_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPainterPath::Element::isCurveTo()const", __qt_this)
        __java_return_value = __qt_this->isCurveTo();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPainterPath::Element::isLineTo()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_isLineTo_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPainterPath::Element::isLineTo()const", __qt_this)
        __java_return_value = __qt_this->isLineTo();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPainterPath::Element::isMoveTo()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_isMoveTo_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPainterPath::Element::isMoveTo()const", __qt_this)
        __java_return_value = __qt_this->isMoveTo();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPainterPath::Element::operator QPointF()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_toPoint_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPainterPath::Element::operator QPointF()const", __qt_this)
        QPointF __qt_return_value = *__qt_this;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPainterPath::Element::operator==(QPainterPath::Element)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_equals_1native_1cref_1QPainterPath_1Element_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID e0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPainterPath::Element::operator==(QPainterPath::Element)const", __qt_this)
        const QPainterPath::Element& __qt_e0 = QtJambiAPI::valueReferenceFromNativeId<QPainterPath::Element>(e0);
        __java_return_value = (*__qt_this) == __qt_e0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_type_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QPainterPath::ElementType&  __qt_value = __qt_this->type;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_x_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->x;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_y_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->y;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPainterPath_00024Element_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPainterPath::Element *__qt_this = QtJambiAPI::objectFromNativeId<QPainterPath::Element>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPainterPath_Element(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPainterPath::Element>("QPainterPath::Element", "io/qt/gui/QPainterPath$Element");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPainterPath_Element, {
        ConstructorInfo(&__qt_construct_QPainterPath_Element, nullptr)
       ,ConstructorInfo(&__qt_construct_QPainterPath_Element_cref_QPainterPath_Element, "Lio/qt/gui/QPainterPath$Element;")
       ,ConstructorInfo(&__qt_construct_QPainterPath_Element_qreal_qreal_QPainterPath_ElementType, "DDLio/qt/gui/QPainterPath$ElementType;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPainterPath_Element);
    registerMetaType<QPainterPath::Element>("QPainterPath::Element");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
